@@ -13,9 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *      Jasper St. Pierre <jstpierre@mecheye.net>
@@ -30,7 +28,7 @@
 #include "gsm-shell-extensions.h"
 
 #define SHELL_SCHEMA "org.gnome.shell"
-#define ENABLED_EXTENSIONS_KEY "enabled-extensions"
+#define DISABLE_EXTENSIONS_KEY "disable-user-extensions"
 
 #define SHELL_EXTENSIONS_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GSM_TYPE_SHELL_EXTENSIONS, GsmShellExtensionsPrivate))
 
@@ -186,9 +184,9 @@ gsm_shell_extensions_init (GsmShellExtensions *self)
 gboolean
 gsm_shell_extensions_disable_all (GsmShellExtensions *self)
 {
-  return g_settings_set_strv (self->priv->settings,
-                              ENABLED_EXTENSIONS_KEY,
-                              NULL);
+  return g_settings_set_boolean (self->priv->settings,
+                                 DISABLE_EXTENSIONS_KEY,
+                                 TRUE);
 }
 
 guint
